@@ -46,7 +46,7 @@ qx.Class.define("callbackery.ui.Popup", {
         this.addListener('appear',function(){
             this.center()
         },this);
-        this.getApplicationRoot().addListener('resize',function(){
+        screen.getApplicationRoot().addListener('resize',function(){
             this.center()
         },this);
 
