@@ -64,6 +64,14 @@ qx.Class.define('callbackery.ui.plugin.Table', {
             }).set({
                 showCellFocusIndicator: false
             });
+            var ctxMenu = this._action.getTableContextMenu();
+            if (ctxMenu){
+                table.setContextMenu(ctxMenu);
+            }
+            var defaultAction = this._action.getDefaultAction();
+            if (defaultAction){
+                table.addListener('cellDbltap',defaultAction,this._action);
+            }
             var resizeBehavior = table.getTableColumnModel().getBehavior();
             cfg.table.forEach(function(col,i){
                 var tcm = table.getTableColumnModel();
